pub struct GenerativeRepair { /* private fields */ }Expand description
Generative repair engine for synthesizing Rust code from HIR
Implementations
Sourceimpl GenerativeRepair
impl GenerativeRepair
Sourcepub fn with_config(config: GenerativeRepairConfig) -> Self
pub fn with_config(config: GenerativeRepairConfig) -> Self
Create a new generative repair engine with custom config
Sourcepub fn synthesize(&self, _hir: &HirModule) -> Result<TokenStream>
pub fn synthesize(&self, _hir: &HirModule) -> Result<TokenStream>
Stub implementation when generative feature is disabled
Sourcepub fn config(&self) -> &GenerativeRepairConfig
pub fn config(&self) -> &GenerativeRepairConfig
Get the current configuration