pub struct PytestExtractor {
pub strict_test_files: bool,
}Expand description
Extracts simple assert statements from pytest files
Fields
strict_test_files: boolOnly extract from test_*.py files
Implementations
Sourceimpl PytestExtractor
impl PytestExtractor
Sourcepub fn with_strict_test_files(self, strict: bool) -> Self
pub fn with_strict_test_files(self, strict: bool) -> Self
Configure whether to only extract from test_*.py files
Sourcepub fn extract(&self, source: &str) -> Result<Vec<Doctest>>
pub fn extract(&self, source: &str) -> Result<Vec<Doctest>>
Extract all simple assertions from Python test source code
Sourcepub fn extract_to_result(
&self,
source: &str,
filename: &str,
) -> Result<PytestResult>
pub fn extract_to_result( &self, source: &str, filename: &str, ) -> Result<PytestResult>
Extract assertions to the same format as doctest results